@@ -1,4 +1,7 @@
-//! All data structures needed for parsing only [`crate::DF::ADSB`] or [`crate::DF::TisB`]
+//! All data structures needed for parsing [`DF::ADSB`] or [`DF::TisB`] messages
+//!
+//! [`DF::ADSB`]: crate::DF::ADSB
+//! [`DF::TisB`]: crate::DF::TisB
 
 use std::fmt::Write;
 
@@ -18,8 +21,7 @@ pub struct ADSB {
     /// Message, extended Squitter
     pub me: ME,
     /// Parity/Interrogator ID
-    #[deku(bits = "24")]
-    pub pi: u32,
+    pub pi: ICAO,
 }
 
 impl ADSB {
@@ -48,28 +50,40 @@ impl ADSB {
 pub enum ME {
     #[deku(id = "0")]
     NoPosition([u8; 6]),
+
     #[deku(id_pat = "1..=4")]
     AircraftIdentification(Identification),
+
     #[deku(id_pat = "5..=8")]
     SurfacePosition(SurfacePosition),
+
     #[deku(id_pat = "9..=18")]
     AirbornePositionBaroAltitude(Altitude),
+
     #[deku(id = "19")]
     AirborneVelocity(AirborneVelocity),
+
     #[deku(id_pat = "20..=22")]
     AirbornePositionGNSSAltitude(Altitude),
+
     #[deku(id = "23")]
     Reserved0([u8; 6]),
+
     #[deku(id_pat = "24")]
     SurfaceSystemStatus([u8; 6]),
+
     #[deku(id_pat = "25..=27")]
     Reserved1([u8; 6]),
+
     #[deku(id = "28")]
     AircraftStatus(AircraftStatus),
+
     #[deku(id = "29")]
     TargetStateAndStatusInformation(TargetStateAndStatusInformation),
+
     #[deku(id = "30")]
     AircraftOperationalCoordination([u8; 6]),
+
     #[deku(id = "31")]
     AircraftOperationStatus(OperationStatus),
 }
@@ -95,8 +109,8 @@ impl ME {
                     " Extended Squitter{}No position information",
                     transponder
                 )?;
-                writeln!(f, "  Address:       {} {}", icao, address_type)?;
-                writeln!(f, "  Air/Ground:    {}", capability)?;
+                writeln!(f, "  Address:       {icao} {address_type}")?;
+                writeln!(f, "  Air/Ground:    {capability}")?;
             },
             ME::AircraftIdentification(Identification { tc, ca, cn }) => {
                 writeln!(
@@ -104,14 +118,14 @@ impl ME {
                     " Extended Squitter{}Aircraft identification and category",
                     transponder
                 )?;
-                writeln!(f, "  Address:       {} {}", icao, address_type)?;
-                writeln!(f, "  Air/Ground:    {}", capability)?;
-                writeln!(f, "  Ident:         {}", cn)?;
-                writeln!(f, "  Category:      {}{}", tc, ca)?;
+                writeln!(f, "  Address:       {icao} {address_type}")?;
+                writeln!(f, "  Air/Ground:    {capability}")?;
+                writeln!(f, "  Ident:         {cn}")?;
+                writeln!(f, "  Category:      {tc}{ca}")?;
             },
             ME::SurfacePosition(..) => {
-                writeln!(f, " Extended Squitter{}Surface position", transponder)?;
-                writeln!(f, "  Address:       {} {}", icao, address_type)?;
+                writeln!(f, " Extended Squitter{transponder}Surface position")?;
+                writeln!(f, "  Address:       {icao} {address_type}")?;
             },
             ME::AirbornePositionBaroAltitude(altitude) => {
                 writeln!(
@@ -119,20 +133,19 @@ impl ME {
                     " Extended Squitter{}Airborne position (barometric altitude)",
                     transponder
                 )?;
-                writeln!(f, "  Address:       {} {}", icao, address_type)?;
-                writeln!(f, "  Air/Ground:    {}", capability)?;
+                writeln!(f, "  Address:       {icao} {address_type}")?;
+                writeln!(f, "  Air/Ground:    {capability}")?;
                 write!(f, "{}", altitude)?;
             },
-            ME::AirborneVelocity(airborne_velocity) => {
-                if let AirborneVelocitySubType::GroundSpeedDecoding(_) = &airborne_velocity.sub_type
-                {
+            ME::AirborneVelocity(airborne_velocity) => match &airborne_velocity.sub_type {
+                AirborneVelocitySubType::GroundSpeedDecoding(_) => {
                     writeln!(
                         f,
                         " Extended Squitter{}Airborne velocity over ground, subsonic",
                         transponder
                     )?;
-                    writeln!(f, "  Address:       {} {}", icao, address_type)?;
-                    writeln!(f, "  Air/Ground:    {}", capability)?;
+                    writeln!(f, "  Address:       {icao} {address_type}")?;
+                    writeln!(f, "  Air/Ground:    {capability}")?;
                     writeln!(
                         f,
                         "  GNSS delta:    {}{} ft",
@@ -155,17 +168,14 @@ impl ME {
                     } else {
                         writeln!(f, "  Invalid packet")?;
                     }
-                }
-                if let AirborneVelocitySubType::AirspeedDecoding(airspeed_decoding) =
-                    &airborne_velocity.sub_type
-                {
+                },
+                AirborneVelocitySubType::AirspeedDecoding(airspeed_decoding) => {
                     writeln!(
                         f,
-                        " Extended Squitter{}Airspeed and heading, subsonic",
-                        transponder
+                        " Extended Squitter{transponder}Airspeed and heading, subsonic",
                     )?;
-                    writeln!(f, "  Address:       {} {}", icao, address_type)?;
-                    writeln!(f, "  Air/Ground:    {}", capability)?;
+                    writeln!(f, "  Address:       {icao} {address_type}")?;
+                    writeln!(f, "  Air/Ground:    {capability}")?;
                     writeln!(f, "  IAS:           {} kt", airspeed_decoding.airspeed)?;
                     if airborne_velocity.vrate_value > 0 {
                         writeln!(
@@ -176,30 +186,35 @@ impl ME {
                         )?;
                     }
                     writeln!(f, "  NACv:          {}", airborne_velocity.nac_v)?;
-                }
+                },
+                AirborneVelocitySubType::Reserved0(_) | AirborneVelocitySubType::Reserved1(_) => {
+                    writeln!(
+                        f,
+                        " Extended Squitter{transponder}Airborne Velocity status (reserved)",
+                    )?;
+                    writeln!(f, "  Address:       {icao} {address_type}")?;
+                },
             },
             ME::AirbornePositionGNSSAltitude(altitude) => {
                 writeln!(
                     f,
-                    " Extended Squitter{}Airborne position (GNSS altitude)",
-                    transponder
+                    " Extended Squitter{transponder}Airborne position (GNSS altitude)",
                 )?;
-                writeln!(f, "  Address:      {} {}", icao, address_type)?;
+                writeln!(f, "  Address:      {icao} {address_type}")?;
                 write!(f, "{}", altitude)?;
             },
             ME::Reserved0(_) | ME::Reserved1(_) => {
-                writeln!(f, " Extended Squitter{}Unknown", transponder)?;
-                writeln!(f, "  Address:       {} {}", icao, address_type)?;
-                writeln!(f, "  Air/Ground:    {}", capability)?;
+                writeln!(f, " Extended Squitter{transponder}Unknown")?;
+                writeln!(f, "  Address:       {icao} {address_type}")?;
+                writeln!(f, "  Air/Ground:    {capability}")?;
             },
             ME::SurfaceSystemStatus(_) => {
                 writeln!(
                     f,
-                    " Extended Squitter{}Reserved for surface system status",
-                    transponder
+                    " Extended Squitter{transponder}Reserved for surface system status",
                 )?;
-                writeln!(f, "  Address:       {} {}", icao, address_type)?;
-                writeln!(f, "  Air/Ground:    {}", capability)?;
+                writeln!(f, "  Address:       {icao} {address_type}")?;
+                writeln!(f, "  Air/Ground:    {capability}")?;
             },
             ME::AircraftStatus(AircraftStatus {
                 emergency_state,
@@ -208,22 +223,20 @@ impl ME {
             }) => {
                 writeln!(
                     f,
-                    " Extended Squitter{}Emergency/priority status",
-                    transponder
+                    " Extended Squitter{transponder}Emergency/priority status",
                 )?;
-                writeln!(f, "  Address:       {} {}", icao, address_type)?;
-                writeln!(f, "  Air/Ground:    {}", capability)?;
-                writeln!(f, "  Squawk:        {:x?}", squawk)?;
-                writeln!(f, "  Emergency/priority:    {}", emergency_state)?;
+                writeln!(f, "  Address:       {icao} {address_type}")?;
+                writeln!(f, "  Air/Ground:    {capability}")?;
+                writeln!(f, "  Squawk:        {squawk:x?}")?;
+                writeln!(f, "  Emergency/priority:    {emergency_state}")?;
             },
             ME::TargetStateAndStatusInformation(target_info) => {
                 writeln!(
                     f,
-                    " Extended Squitter{}Target state and status (V2)",
-                    transponder
+                    " Extended Squitter{transponder}Target state and status (V2)",
                 )?;
-                writeln!(f, "  Address:       {} {}", icao, address_type)?;
-                writeln!(f, "  Air/Ground:    {}", capability)?;
+                writeln!(f, "  Address:       {icao} {address_type}")?;
+                writeln!(f, "  Air/Ground:    {capability}")?;
                 writeln!(f, "  Target State and Status:")?;
                 writeln!(f, "    Target altitude:   MCP, {} ft", target_info.altitude)?;
                 writeln!(f, "    Altimeter setting: {} millibars", target_info.qnh)?;
@@ -231,18 +244,18 @@ impl ME {
                     writeln!(f, "    Target heading:    {}", target_info.heading)?;
                 }
                 if target_info.tcas {
-                    write!(f, "    ACAS:              operational")?;
+                    write!(f, "    ACAS:              operational ")?;
                     if target_info.autopilot {
-                        write!(f, " autopilot ")?;
+                        write!(f, "autopilot ")?;
                     }
-                    if target_info.vnav {
-                        write!(f, " VNAC ")?;
+                    if target_info.vnac {
+                        write!(f, "vnav ")?;
                     }
                     if target_info.alt_hold {
                         write!(f, "altitude-hold ")?;
                     }
                     if target_info.approach {
-                        write!(f, "approach")?;
+                        write!(f, " approach")?;
                     }
                     writeln!(f)?;
                 } else {
@@ -256,30 +269,34 @@ impl ME {
             ME::AircraftOperationalCoordination(_) => {
                 writeln!(
                     f,
-                    " Extended Squitter{}Aircraft Operational Coordination",
-                    transponder
+                    " Extended Squitter{transponder}Aircraft Operational Coordination",
                 )?;
                 writeln!(f, "  Address:       {} {}", icao, address_type)?;
             },
             ME::AircraftOperationStatus(OperationStatus::Airborne(opstatus_airborne)) => {
                 writeln!(
                     f,
-                    " Extended Squitter{}Aircraft operational status (airborne)",
-                    transponder
+                    " Extended Squitter{transponder}Aircraft operational status (airborne)",
                 )?;
-                writeln!(f, " Address:       {} {}", icao, address_type)?;
-                writeln!(f, " Air/Ground:    {}", capability)?;
-                write!(f, " Aircraft Operational Status:\n{}", opstatus_airborne)?;
+                writeln!(f, "  Address:       {icao} {address_type}")?;
+                writeln!(f, "  Air/Ground:    {capability}")?;
+                write!(f, "  Aircraft Operational Status:\n{opstatus_airborne}")?;
             },
             ME::AircraftOperationStatus(OperationStatus::Surface(opstatus_surface)) => {
                 writeln!(
                     f,
-                    " Extended Squitter{}Aircraft operational status (surface)",
-                    transponder
+                    " Extended Squitter{transponder}Aircraft operational status (surface)",
                 )?;
-                writeln!(f, " Address:       {} {}", icao, address_type)?;
-                writeln!(f, " Air/Ground:    {}", capability)?;
-                write!(f, " Aircraft Operational Status:\n {}", opstatus_surface)?;
+                writeln!(f, "  Address:       {icao} {address_type}")?;
+                writeln!(f, "  Air/Ground:    {capability}")?;
+                write!(f, "  Aircraft Operational Status:\n {opstatus_surface}")?;
+            },
+            ME::AircraftOperationStatus(OperationStatus::Reserved(..)) => {
+                writeln!(
+                    f,
+                    " Extended Squitter{transponder}Aircraft operational status (reserved)",
+                )?;
+                writeln!(f, "  Address:       {icao} {address_type}")?;
             },
         }
         Ok(f)
@@ -320,8 +337,12 @@ pub struct AirspeedDecoding {
 pub enum OperationStatus {
     #[deku(id = "0")]
     Airborne(OperationStatusAirborne),
+
     #[deku(id = "1")]
     Surface(OperationStatusSurface),
+
+    #[deku(id_pat = "2..=7")]
+    Reserved(#[deku(bits = "5")] u8, [u8; 5]),
 }
 
 /// [`ME::AircraftOperationStatus`] && [`OperationStatus`] == 0
@@ -572,7 +593,7 @@ impl std::fmt::Display for CapabilityClassSurface {
     }
 }
 
-/// OperationMode field not including the last 8 bits that are different for Surface/Airborne
+/// `OperationMode` field not including the last 8 bits that are different for Surface/Airborne
 #[derive(Debug, PartialEq, DekuRead, Copy, Clone)]
 pub struct OperationalMode {
     /// (0, 0) in Version 2, reserved for other values
@@ -681,7 +702,7 @@ pub enum ControlField {
 impl std::fmt::Display for ControlField {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match self {
-            Self::ADSB_ES_NT(adsb_icao) => {
+            Self::ADSB_ES_NT(adsb_icao) | Self::ADSB_ES_NT_ALT(adsb_icao) => {
                 write!(
                     f,
                     "{}",
@@ -691,27 +712,9 @@ impl std::fmt::Display for ControlField {
                         .unwrap()
                 )?;
             },
-            Self::ADSB_ES_NT_ALT(adsb_icao) => {
-                write!(
-                    f,
-                    "{}",
-                    adsb_icao
-                        .me
-                        .to_string(adsb_icao.aa, "(ADS-B)", Capability::AG_UNCERTAIN3, false,)
-                        .unwrap()
-                )?;
-            },
-            Self::TISB_FINE(adsb_icao) => {
-                write!(
-                    f,
-                    "{}",
-                    adsb_icao
-                        .me
-                        .to_string(adsb_icao.aa, "(TIS-B)", Capability::AG_UNCERTAIN3, false,)
-                        .unwrap()
-                )?;
-            },
-            Self::TISB_COARSE(adsb_icao) => {
+            Self::TISB_COARSE(adsb_icao)
+            | Self::TISB_ADSB_RELAY(adsb_icao)
+            | Self::TISB_FINE(adsb_icao) => {
                 write!(
                     f,
                     "{}",
@@ -724,16 +727,6 @@ impl std::fmt::Display for ControlField {
             Self::TISB_MANAGE(tisb_manage) => {
                 write!(f, " Address:   {} (ADS-R)", tisb_manage.aa)?;
             },
-            Self::TISB_ADSB_RELAY(adsb_icao) => {
-                write!(
-                    f,
-                    "{}",
-                    adsb_icao
-                        .me
-                        .to_string(adsb_icao.aa, "(TIS-B)", Capability::AG_UNCERTAIN3, false,)
-                        .unwrap()
-                )?;
-            },
             Self::TISB_ADSB(tisb_adsb) => {
                 write!(
                     f,
@@ -807,6 +800,8 @@ pub enum AircraftStatusType {
     NoInformation,
     #[deku(id = "1")]
     EmergencyPriorityStatus,
+    #[deku(id = "2")]
+    ACASRaBroadcast,
     #[deku(id_pat = "_")]
     Reserved,
 }
@@ -852,7 +847,7 @@ pub struct OperationCodeSurface {
     #[deku(bits = "3")]
     pub lw: u8,
     #[deku(bits = "6")]
-    pub reserved: u16,
+    pub reserved: u8,
 }
 
 #[derive(Debug, PartialEq, DekuRead, Clone)]
@@ -888,9 +883,11 @@ impl std::fmt::Display for TypeCoding {
     }
 }
 
+/// Target State and Status (§2.2.3.2.7.1)
 #[derive(Copy, Clone, Debug, PartialEq, DekuRead)]
 pub struct TargetStateAndStatusInformation {
-    // TODO Support V1
+    // TODO Support Target State and Status defined in DO-260A, ADS-B Version=1
+    // TODO Support reserved 2..=3
     #[deku(bits = "2")]
     pub subtype: u8,
     #[deku(bits = "1")]
@@ -926,7 +923,7 @@ pub struct TargetStateAndStatusInformation {
     #[deku(bits = "1")]
     pub autopilot: bool,
     #[deku(bits = "1")]
-    pub vnav: bool,
+    pub vnac: bool,
     #[deku(bits = "1")]
     pub alt_hold: bool,
     #[deku(bits = "1")]
@@ -965,7 +962,8 @@ pub struct AirborneVelocity {
 }
 
 impl AirborneVelocity {
-    /// Return effective (heading, ground_speed, vertical_rate) for groundspeed
+    /// Return effective (heading, `ground_speed`, `vertical_rate`) for groundspeed
+    #[must_use]
     pub fn calculate(&self) -> Option<(f64, f64, i16)> {
         if let AirborneVelocitySubType::GroundSpeedDecoding(ground_speed) = &self.sub_type {
             let v_ew = f64::from((ground_speed.ew_vel as i16 - 1) * ground_speed.ew_sign.value());
@@ -987,14 +985,21 @@ impl AirborneVelocity {
     }
 }
 
-/// [`ME::AirborneVelocity`]
+/// Airborne Velocity Message “Subtype” Code Field Encoding
 #[derive(Debug, PartialEq, DekuRead, Clone)]
 #[deku(ctx = "st: u8", id = "st")]
 pub enum AirborneVelocitySubType {
+    #[deku(id = "0")]
+    Reserved0(#[deku(bits = "22")] u32),
+
     #[deku(id_pat = "1..=2")]
     GroundSpeedDecoding(GroundSpeedDecoding),
+
     #[deku(id_pat = "3..=4")]
     AirspeedDecoding(AirspeedDecoding),
+
+    #[deku(id_pat = "5..=7")]
+    Reserved1(#[deku(bits = "22")] u32),
 }
 
 #[derive(Copy, Clone, Debug, PartialEq, DekuRead)]
