@@ -1,10 +1,8 @@
-#![doc(
-    html_logo_url = "https://raw.githubusercontent.com/wcampbell0x2a/adsb_deku/master/media/logo.png"
-)]
+#![doc(html_logo_url = "https://raw.githubusercontent.com/rsadsb/adsb_deku/master/media/logo.png")]
 /*!
 `adsb_deku` provides decoding for the [`ADS-B`] Downlink protocol by using the [`deku`] crate.
 
-## Downlink Format support
+# Downlink Format Support
 |  [`DF`]  |  Name                               |  Section    |
 | -------- | ----------------------------------- | ----------- |
 | 0        | [`Short Air-Air Surveillance`]      | 3.1.2.8.2   |
@@ -27,7 +25,7 @@
 | (1,0)     | [`Data Link Capability`]                | A-2-16      |
 | (2,0)     | [`Aircraft Identification`]             | A-2-32      |
 
-# [`Extended Squitter(ADS-B)`] and [`Extended Squitter(TIS-B)`] Type Code support
+# [`Extended Squitter(ADS-B)`] and [`Extended Squitter(TIS-B)`] Type Code Support
 
 |  [`ME`](Type Code)  |  Name                                  |
 | ------------------- | -----------------------------------    |
@@ -107,14 +105,11 @@ different `adsb_deku` uses. See the [`README.md`] for examples of use.
 [`ME::AircraftOperationalCoordination`]: crate::adsb::ME::AircraftOperationalCoordination
 [`ME::AircraftOperationStatus`]: crate::adsb::ME::AircraftOperationStatus
 
-[`apps`]: crate::Frame
-[`Frame`]: crate::Frame
-[`deku::DekuContainerRead`]: crate::deku::DekuContainerRead
-[`README.md`]: https://github.com/wcampbell0x2a/adsb_deku/blob/master/README.md
-[`apps/`]: https://github.com/wcampbell0x2a/adsb_deku/tree/master/apps
+[`README.md`]: https://github.com/rsadsb/adsb_deku/blob/master/README.md
+[`apps/`]: https://github.com/rsadsb/adsb_deku/tree/master/apps
 [`ADS-B`]: https://en.wikipedia.org/wiki/Automatic_Dependent_Surveillance%E2%80%93Broadcast
 [`deku`]: https://github.com/sharksforarms/deku
-!*/
+*/
 
 // good reference: http://www.anteni.net/adsb/Doc/1090-WP30-18-DRAFT_DO-260B-V42.pdf
 //
@@ -129,6 +124,9 @@ pub mod cpr;
 mod crc;
 mod mode_ac;
 
+#[doc = include_str!("../README.md")]
+mod readme_test {}
+
 use adsb::{ControlField, ADSB};
 use bds::BDS;
 use deku::bitvec::{BitSlice, Msb0};
@@ -171,45 +169,50 @@ impl Frame {
 
 impl std::fmt::Display for Frame {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        let crc = self.crc;
         match &self.df {
             DF::ShortAirAirSurveillance { altitude, .. } => {
                 writeln!(f, " Short Air-Air Surveillance")?;
-                writeln!(f, "  ICAO Address:  {:06x} (Mode S / ADS-B)", self.crc)?;
+                writeln!(f, "  ICAO Address:  {crc:06x} (Mode S / ADS-B)")?;
                 if altitude.0 > 0 {
+                    let altitude = altitude.0;
                     writeln!(f, "  Air/Ground:    airborne?")?;
-                    writeln!(f, "  Altitude:      {} ft barometric", altitude.0)?;
+                    writeln!(f, "  Altitude:      {altitude} ft barometric")?;
                 } else {
                     writeln!(f, "  Air/Ground:    ground")?;
                 }
             },
             DF::SurveillanceAltitudeReply { fs, ac, .. } => {
                 writeln!(f, " Surveillance, Altitude Reply")?;
-                writeln!(f, "  ICAO Address:  {:06x} (Mode S / ADS-B)", self.crc)?;
-                writeln!(f, "  Air/Ground:    {}", fs)?;
+                writeln!(f, "  ICAO Address:  {crc:06x} (Mode S / ADS-B)")?;
+                writeln!(f, "  Air/Ground:    {fs}")?;
                 if ac.0 > 0 {
-                    writeln!(f, "  Altitude:      {} ft barometric", ac.0)?;
+                    let altitude = ac.0;
+                    writeln!(f, "  Altitude:      {altitude} ft barometric")?;
                 }
             },
             DF::SurveillanceIdentityReply { fs, id, .. } => {
+                let identity = id.0;
                 writeln!(f, " Surveillance, Identity Reply")?;
-                writeln!(f, "  ICAO Address:  {:06x} (Mode S / ADS-B)", self.crc)?;
-                writeln!(f, "  Air/Ground:    {}", fs)?;
-                writeln!(f, "  Identity:      {:04x}", id.0)?;
+                writeln!(f, "  ICAO Address:  {crc:06x} (Mode S / ADS-B)")?;
+                writeln!(f, "  Air/Ground:    {fs}")?;
+                writeln!(f, "  Identity:      {identity:04x}")?;
             },
             DF::AllCallReply {
                 capability, icao, ..
             } => {
                 writeln!(f, " All Call Reply")?;
-                writeln!(f, "  ICAO Address:  {} (Mode S / ADS-B)", icao)?;
-                writeln!(f, "  Air/Ground:    {}", capability)?;
+                writeln!(f, "  ICAO Address:  {icao} (Mode S / ADS-B)")?;
+                writeln!(f, "  Air/Ground:    {capability}")?;
             },
             DF::LongAirAir { altitude, .. } => {
                 writeln!(f, " Long Air-Air ACAS")?;
-                writeln!(f, "  ICAO Address:  {:06x} (Mode S / ADS-B)", self.crc)?;
+                writeln!(f, "  ICAO Address:  {crc:06x} (Mode S / ADS-B)")?;
                 // TODO the airborne? should't be static
                 if altitude.0 > 0 {
+                    let altitude = altitude.0;
                     writeln!(f, "  Air/Ground:    airborne?")?;
-                    writeln!(f, "  Baro altitude: {} ft", altitude.0)?;
+                    writeln!(f, "  Baro altitude: {altitude} ft")?;
                 } else {
                     writeln!(f, "  Air/Ground:    ground")?;
                 }
@@ -224,19 +227,20 @@ impl std::fmt::Display for Frame {
             DF::ExtendedQuitterMilitaryApplication { .. } => {},
             DF::CommBAltitudeReply { bds, alt, .. } => {
                 writeln!(f, " Comm-B, Altitude Reply")?;
-                writeln!(f, "  ICAO Address:  {:x?} (Mode S / ADS-B)", self.crc)?;
-                writeln!(f, "  Altitude:      {} ft", alt.0)?;
+                writeln!(f, "  ICAO Address:  {crc:x?} (Mode S / ADS-B)")?;
+                let altitude = alt.0;
+                writeln!(f, "  Altitude:      {altitude} ft")?;
                 write!(f, "  {}", bds)?;
             },
             DF::CommBIdentityReply { id, bds, .. } => {
                 writeln!(f, " Comm-B, Identity Reply")?;
-                writeln!(f, "    ICAO Address:  {:x?} (Mode S / ADS-B)", self.crc)?;
-                writeln!(f, "    Squawk:        {:x?}", id)?;
+                writeln!(f, "    ICAO Address:  {crc:x?} (Mode S / ADS-B)")?;
+                writeln!(f, "    Squawk:        {id:x?}")?;
                 write!(f, "    {}", bds)?;
             },
             DF::CommDExtendedLengthMessage { .. } => {
                 writeln!(f, " Comm-D Extended Length Message")?;
-                writeln!(f, "    ICAO Address:     {:x?} (Mode S / ADS-B)", self.crc)?;
+                writeln!(f, "    ICAO Address:     {crc:x?} (Mode S / ADS-B)")?;
             },
         }
         Ok(())
@@ -428,7 +432,7 @@ pub enum DF {
     },
 }
 
-/// [`DF::CommBAltitudeReply`] || ([`DF::ADSB`] && ([`adsb::ME::AirbornePositionBaroAltitude`] || [`adsb::ME::AirbornePositionGNSSAltitude`])
+/// Latitude, Longitude and Altitude information
 #[derive(Debug, PartialEq, DekuRead, Default, Copy, Clone)]
 pub struct Altitude {
     #[deku(bits = "5")]
@@ -461,7 +465,7 @@ impl std::fmt::Display for Altitude {
 }
 
 impl Altitude {
-    /// decodeAC12Field
+    /// `decodeAC12Field`
     fn read(rest: &BitSlice<Msb0, u8>) -> Result<(&BitSlice<Msb0, u8>, u32), DekuError> {
         let (rest, num) = u32::read(rest, (deku::ctx::Endian::Big, deku::ctx::Size::Bits(12)))?;
 
@@ -487,6 +491,7 @@ impl Altitude {
     }
 }
 
+/// SPI Condition
 #[derive(Debug, PartialEq, DekuRead, Copy, Clone)]
 #[deku(type = "u8", bits = "2")]
 pub enum SurveillanceStatus {
@@ -538,6 +543,7 @@ pub enum Sign {
 }
 
 impl Sign {
+    #[must_use]
     pub fn value(&self) -> i16 {
         match self {
             Self::Positive => 1,
@@ -603,7 +609,7 @@ impl std::fmt::Display for ICAO {
     }
 }
 
-/// Type of DownlinkRequest
+/// Type of `DownlinkRequest`
 #[derive(Debug, PartialEq, DekuRead, Copy, Clone)]
 #[deku(type = "u8", bits = "5")]
 pub enum DownlinkRequest {
@@ -630,6 +636,7 @@ pub struct UtilityMessage {
     pub ids: UtilityMessageType,
 }
 
+/// Message Type
 #[derive(Debug, PartialEq, DekuRead, Copy, Clone)]
 #[deku(type = "u8", bits = "2")]
 pub enum UtilityMessageType {
