@@ -280,9 +280,9 @@ fn testing_df_extendedsquitteraircraftopstatus() {
     let resulting_string = format!("{}", frame);
     assert_eq!(
         r#" Extended Squitter Aircraft operational status (airborne)
- Address:       0d097e (Mode S / ADS-B)
- Air/Ground:    airborne
- Aircraft Operational Status:
+  Address:       0d097e (Mode S / ADS-B)
+  Air/Ground:    airborne
+  Aircraft Operational Status:
    Version:            2
    Capability classes: ACAS ARV TS
    Operational modes:  SAF SDA=3
@@ -301,9 +301,9 @@ fn testing_df_extendedsquitteraircraftopstatus() {
     let resulting_string = format!("{}", frame);
     assert_eq!(
         r#" Extended Squitter Aircraft operational status (airborne)
- Address:       a1a8da (Mode S / ADS-B)
- Air/Ground:    airborne
- Aircraft Operational Status:
+  Address:       a1a8da (Mode S / ADS-B)
+  Air/Ground:    airborne
+  Aircraft Operational Status:
    Version:            2
    Capability classes: ACAS ARV TS
    Operational modes:  SAF SDA=2
@@ -482,7 +482,7 @@ fn testing_issue_01() {
     Target altitude:   MCP, 36000 ft
     Altimeter setting: 1013.6 millibars
     Target heading:    315
-    ACAS:              operational
+    ACAS:              operational 
     NACp:              8
     NICbaro:           1
     SIL:               3 (per sample)
@@ -659,9 +659,9 @@ fn testing_df_18() {
     let resulting_string = format!("{}", frame);
     assert_eq!(
         r#" Extended Squitter (Non-Transponder) Aircraft operational status (surface)
- Address:       a4d01f (ADS-R)
- Air/Ground:    airborne?
- Aircraft Operational Status:
+  Address:       a4d01f (ADS-R)
+  Air/Ground:    airborne?
+  Aircraft Operational Status:
    Version:            2
    NIC-A:              0
    NIC-C:              0
@@ -919,3 +919,51 @@ fn test_operational_coordination() {
         resulting_string
     );
 }
+
+#[test]
+fn test_issue_25() {
+    let bytes = hex!("92479249fcb22e16fbdc3bac5b56");
+    let frame = Frame::from_bytes((&bytes, 0)).unwrap().1;
+    let resulting_string = format!("{}", frame);
+    assert_eq!(
+        r#" Extended Squitter (Non-Transponder) Aircraft operational status (reserved)
+  Address:       479249 (TIS-B)
+"#,
+        resulting_string
+    );
+}
+
+#[test]
+fn test_issue_22() {
+    let bytes = hex!("911c059d9805a452cf109f64924f");
+    let frame = Frame::from_bytes((&bytes, 0)).unwrap().1;
+    let resulting_string = format!("{}", frame);
+    assert_eq!(
+        r#" Extended Squitter (Non-Transponder) Airborne Velocity status (reserved)
+  Address:       1c059d (ADS-B)
+"#,
+        resulting_string
+    );
+}
+
+#[test]
+fn test_df17_error() {
+    let bytes = hex!("8da04e60ea3ab860015f889746a9");
+    let frame = Frame::from_bytes((&bytes, 0)).unwrap().1;
+    let resulting_string = format!("{}", frame);
+    assert_eq!(
+        r#" Extended Squitter Target state and status (V2)
+  Address:       a04e60 (Mode S / ADS-B)
+  Air/Ground:    airborne
+  Target State and Status:
+    Target altitude:   MCP, 30016 ft
+    Altimeter setting: 1013.6 millibars
+    ACAS:              operational autopilot vnav 
+    NACp:              10
+    NICbaro:           1
+    SIL:               3 (per sample)
+    QNH:               1013.6 millibars
+"#,
+        resulting_string
+    );
+}
